@@ -12,8 +12,10 @@ NEW_SECTION_PATTERN = re.compile(r'^##\s*[\d.]+\s*-\s*[\d-]+$')
 
 def main():
     version = sys.argv[1]
+    if version.endswith('.dev0'):
+        version = version[:-5]
 
-    section_pattern = re.compile(r'^##\s*{0}\s*-\s*[\d-]+$'
+    section_pattern = re.compile(r'^##\s*{0}\s*-\s*.*$'
                                  .format(version.replace('.', '\\.')))
 
     with open(os.path.join(CERTBOT_ROOT, 'certbot', 'CHANGELOG.md')) as file_h:
